@@ -1,8 +1,4 @@
-import os
-from requests import Request, Session
 from libs3tl import Step
-import websocket
-
 
 class Extract(Step.Step):
     def __init__(self):
@@ -10,19 +6,16 @@ class Extract(Step.Step):
         self.step = "Ex"
         self.paramsFile = 'Extract.properties'
         self.logger = 'logExtract'
-        self.logFile =self.getRelativeFile(os.getcwd() +'\../logs/Extract.log')
+        self.logFile =self.getRelativeFile('../logs/Extract.log')
 
     def startup(self):
         super(Extract,self).startup()
 
-    
     def doWorkAndHandoff(self):
         pass
 
     def doWork(self):
         pass
 
-
     
 
-   
